@@ -3,9 +3,9 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from wavefront_api_client.api.access_policy_api import AccessPolicyApi
 from wavefront_api_client.api.account__user_and_service_account_api import AccountUserAndServiceAccountApi
 from wavefront_api_client.api.alert_api import AlertApi
-from wavefront_api_client.api.anomaly_api import AnomalyApi
 from wavefront_api_client.api.api_token_api import ApiTokenApi
 from wavefront_api_client.api.cloud_integration_api import CloudIntegrationApi
 from wavefront_api_client.api.dashboard_api import DashboardApi
